@@ -113,15 +113,16 @@ station / podcast / video in one's own choice of media player software rather
 than using their web browser and accepting flash, ads, javascript, cookies, 
 trackers, web-bugs, and other crapware associated with that method of play.  
 The author created and uses his own custom all-purpose media player called 
-"Fauxdacious" media player (his custom forked version of the open-source 
-"Audacious" audio player).  "Fauxdacious" 
-(L<https://wildstar84.wordpress.com/fauxdacious/>) incorporates this module to 
-decode and play streams, along with their titles / station names, and station 
-/ podcast / video icons, artists / channel names, genres, and descriptions! 
+"Fauxdacious Media Player" (his custom forked version of the open-source 
+"Audacious Audio Player).  "Fauxdacious" 
+(L<https://wildstar84.wordpress.com/fauxdacious/>) incorporates this module via 
+a Perl helper-script to decode and play streams, along with their titles / 
+station names, and station / podcast / video icons, artists / channel names, 
+genres, and descriptions! 
 
 Please NOTE:  StreamFinder is a module, NOT a standalone application.  It is 
 designed to be used by other Perl applications.  To create your own very simple 
-application just to fetch streams manually, simply grab the code in the 
+application just to fetch stream data manually, simply grab the code in the 
 B<SYNOPSIS> section above, save it to an executable text file, ie. 
 I<StreamFinder.pl>, and run it from the command line with a supported streaming 
 site URL as the argument.  You can then edit it to tailor it to your needs.
@@ -137,6 +138,7 @@ goodpods.com podcasts (L<StreamFinder::Goodpods>),
 podcasts.google.com podcasts (L<StreamFinder::Google>), 
 iheartradio.com radio stations and podcasts (L<StreamFinder::IHeartRadio>), 
 www.internetradio.com radio stations (L<StreamFinder::InternetRadio>), 
+www.linktv.org videos (L<StreamFinder::LinkTV>),
 onlineradiobox.com radio stations (L<StreamFinder::OnlineRadiobox>), 
 odysee.com videos (L<StreamFinder::Odysee>), 
 podbean.com podcasts (L<StreamFinder::Podbean>), 
@@ -527,7 +529,7 @@ use strict;
 use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '2.14';
+our $VERSION = '2.15';
 our $DEBUG = 0;
 
 require Exporter;
@@ -536,7 +538,7 @@ require Exporter;
 @EXPORT = qw();
 my @supported_mods = (qw(Anystream Apple Bitchute Blogger BrandNewTube Brighteon Castbox Goodpods 
 		Google IHeartRadio InternetRadio Odysee OnlineRadiobox Podbean PodcastAddict Podchaser 
-		RadioNet Rcast Rumble SermonAudio SoundCloud	Spreaker	Tunein Vimeo Youtube));
+		RadioNet Rcast Rumble SermonAudio SoundCloud	Spreaker	Tunein Vimeo Youtube LinkTV));
 
 my %useit;
 
@@ -639,6 +641,9 @@ sub new
 	} elsif ($url =~ m#\bpodchaser\.# && $useit{'Podchaser'}) {
 		eval { require 'StreamFinder/Podchaser.pm'; $haveit = 1; };
 		return new StreamFinder::Podchaser($url, @args)  if ($haveit);
+	} elsif ($url =~ m#\blinktv\.# && $useit{'LinkTV'}) {
+		eval { require 'StreamFinder/LinkTV.pm'; $haveit = 1; };
+		return new StreamFinder::LinkTV($url, @args)  if ($haveit);
 	} elsif ($useit{'Youtube'}) {  #DEFAULT TO youtube-dl SINCE SO MANY URLS ARE HANDLED THERE NOW.
 		eval { require 'StreamFinder/Youtube.pm'; $haveit = 1; };
 		if ($haveit) {
