@@ -114,14 +114,22 @@ One or more stream URLs can be returned for each podcast.
 =item B<new>(I<ID>|I<url> [, I<-secure> [ => 0|1 ]] [, I<-debug> [ => 0|1|2 ]])
 
 Accepts a podchaser.com podcast-ID, episode-ID or URL and creates and returns a 
-a new podcast object, or I<undef> if the URL is not a valid podcast, or no streams 
-are found.  The URL can be the full URL, ie. 
-https://www.podchaser.com/podcasts/B<podcast-id#>/episode/B<episode-id#>, 
-https://www.podchaser.com/podcasts/B<podcast-id#>, or just 
-B<podcast-id#>/I<episode-id#>.
+a new podcast object, or I<undef> if the URL is not a valid podcast, or no 
+streams are found.  The URL can be the full URL, ie. 
+https://www.podchaser.com/podcasts/B<podcast-id>/episodes/B<episode-id>, 
+https://www.podchaser.com/podcasts/B<podcast-id>, or just 
+B<podcast-id/episode-id> or B<podcast-id>.  I do not (yet) know how to fetch 
+a podchaser.com episode with just the I<episode-ID>, though it IS legal to just 
+supply the numeric part of episode-IDs 
+(as long as you also have the podcast-ID).
 
-The optional I<-secure> argument can be either 0 or 1 (I<false> or I<true>).  If 1 
-then only secure ("https://") streams will be returned.
+Some other URL formats also seem to work well, such as:  
+https://www.podchaser.com/creators/B<creator-id> and 
+https://www.podchaser.com/creators/B<creator-id>/appearances (both formats are 
+podcast pages (multiple episodes).
+
+The optional I<-secure> argument can be either 0 or 1 (I<false> or I<true>).  
+If 1 then only secure ("https://") streams will be returned.
 
 DEFAULT I<-secure> is 0 (false) - return all streams (http and https).
 
@@ -129,8 +137,9 @@ Additional options:
 
 I<-log> => "I<logfile>"
 
-Specify path to a log file.  If a valid and writable file is specified, A line will be 
-appended to this file every time one or more streams is successfully fetched for a url.
+Specify path to a log file.  If a valid and writable file is specified, A line 
+will be appended to this file every time one or more streams is successfully 
+fetched for a url.
 
 DEFAULT I<-none-> (no logging).
 
@@ -138,11 +147,11 @@ I<-logfmt> specifies a format string for lines written to the log file.
 
 DEFAULT "I<[time] [url] - [site]: [title] ([total])>".  
 
-The valid field I<[variables]> are:  [stream]: The url of the first/best stream found.  
-[site]:  The site name (Podchaser).  [url]:  The url searched for streams.  
-[time]: Perl timestamp when the line was logged.  [title], [artist], [album], 
-[description], [year], [genre], [total], [albumartist]:  The corresponding field data 
-returned (or "I<-na->", if no value).
+The valid field I<[variables]> are:  [stream]: The url of the first/best 
+stream found.  [site]:  The site name (Podchaser).  [url]:  The url searched 
+for streams.  [time]: Perl timestamp when the line was logged.  [title], 
+[artist], [album], [description], [year], [genre], [total], [albumartist]:  
+The corresponding field data returned (or "I<-na->", if no value).
 
 =item $podcast->B<get>(['playlist'])
 
@@ -178,15 +187,15 @@ Returns the podcast's title, or (long description).
 =item $podcast->B<getIconURL>(['artist'])
 
 Returns the URL for the podcast's "cover art" icon image, if any.
-If B<'artist'> is specified, the channel artist's icon url is returned, 
-if any.
+If B<'artist'> is specified, the channel/podcast artist's icon url 
+is returned, if any.
 
 =item $podcast->B<getIconData>(['artist'])
 
 Returns a two-element array consisting of the extension (ie. "png", 
 "gif", "jpeg", etc.) and the actual icon image (binary data), if any.
-If B<'artist'> is specified, the channel artist's icon data is returned, 
-if any.
+If B<'artist'> is specified, the channel/podcast artist's icon data 
+is returned, if any.
 
 =item $podcast->B<getImageURL>()
 
@@ -372,7 +381,7 @@ sub new
 
 TRYIT:
 	if ($url2fetch =~ m#^https?\:\/\/#) {
-		if ($url2fetch =~ m#\/episodes\/(.+)$#) {
+		if ($url2fetch =~ m#\/episodes?\/(.+)$#) {
 			$self->{'id'} = $1;
 			$isEpisode = 1;
 		} elsif ($url2fetch =~ m#\/([^\/]+)$#) {
@@ -382,6 +391,13 @@ TRYIT:
 	} else {
 		$self->{'id'} = $url2fetch;
 		$isEpisode = ($url2fetch =~ m#\/#) ? 1 : 0;
+		if ($isEpisode) {
+			my ($podcastID, $episodeID) = split(m#\/#, $self->{'id'});
+			$url2fetch = "https://www.podchaser.com/podcasts/${podcastID}/episodes/${episodeID}";
+			$self->{'id'} = $episodeID;
+		} else {
+			$url2fetch = "https://www.podchaser.com/podcasts/$$self{'id'}";
+		}
 	}
 	return undef  unless ($self->{'id'});  #INVALID ID/URL!
 
@@ -448,93 +464,184 @@ TRYIT:
 		$stream = ($html =~ m#\"video_url\"\:\"([^\"]+)#s) ? $1 : '';
 		$stream ||= $1  if ($html =~ m#\>Download\s+Video\s+File\<\/span\>\<span\s+(class\=\"[^\"]*\"\s+)?title\=\"([^\"]+)#s);
 		unshift(@{$self->{'streams'}}, $stream)  if ($stream);
-		$self->{'cnt'} = scalar(@{$self->{'streams'}});
-
-		if ($DEBUG) {
-			foreach my $i (sort keys %{$self}) {
-				print STDERR "--KEY=$i= VAL=".$self->{$i}."=\n";
-			}
-			print STDERR "--FIRST STREAM=".${$self->{'streams'}}[0]."=\n";
-		}
 	} else {   #PODCAST PAGE:
 		print STDERR "-----WE'RE A PODCAST PAGE: ID=".$self->{'id'}."!\n"  if ($DEBUG);
 
 		#FETCH PODCAST-WIDE METADATA HERE!:
 		$self->{'albumartist'} = $url2fetch;
-		$self->{'articonurl'} = $1  if ($html =~ m#\s+property\=\"(?:og|twiter)\:image\"\s+content\=\"([^\"]+)#s);
+		$self->{'articonurl'} = $1  if ($html =~ m#\"\s+name\=\"image\"\s+content\=\"([^\"]+)#s);
+		$self->{'articonurl'} ||= $1  if ($html =~ m#\s+property\=\"(?:og|twiter)\:image\"\s+content\=\"([^\"]+)#s);
 		$self->{'artist'} = $1  if ($html =~ m#\s+property\=\"title\"\s+content\=\"([^\"]+)#s);
+		if ($html =~ m#\"itunes_owner_name\"\:\"([^\"]+)#s) {
+			$self->{'album'} = $self->{'artist'}  if ($self->{'artist'});
+			$self->{'artist'} = $1;
+		}
 
 		#WE NEED TO EXTRACT 1ST EPISODE ID, BUT WHILST AT IT, GO AHEAD AND FETCH PLAYLIST DATA HERE TOO!:
-		my $ep1url = '';    #FIRST (LATEST) EPISODE PAGE.
-		my $ep1Stream = '';
-		my $ep1Title = '';
 		my %epiHash = ();
+		my %titleHash = ();
 
 		#Podchaser.com PODCAST PAGES HAVE THE LATEST AND/OR FEATURED EPISODE AT THE TOP, BUT OFTEN
-		#REPEATED AGAIN IN THE EPISODE LIST:
+		#(BUT NOT ALWAYS) REPEATED AGAIN IN THE EPISODE LIST:
+		#THE "LATEST EPISODE" MAY NOT ALWAYS BE THE LATEST EITHER, GO FIGURE! :/
 		foreach my $special (qw(latest featured)) {
 			if ($html =~ s#\"${special}_episode\"\:\{([^\}]+)\}##s) {
 				my $latest = $1;
-				if ($latest =~ m#\"audio_url\"\:\"([^\"]+)#s) {
-					my $streamURL = $1;
-					(my $stream = uri_unescape($streamURL)) =~ s#^https?\:\/\/podchaser\.\w+\/episode\/##o;
-					my $title = $1  if ($latest =~ m#\"title\"\:\"([^\"]+)#s);
-					unless (!defined($title) || $self->{'secure'} && $stream !~ /^https/o) {
-						$ep1url = ($latest =~ m#\"id\"\:\"?(\d+)#s) ? $self->{'albumartist'} . '/episodes/' . $1 : $streamURL;
-						$ep1url = $1  if ($latest =~ m#\"url\"\:\"([^\"]+)#s);
-						$ep1Stream = $stream;
-						$ep1Title = $title;
-						$epiHash{$stream} = 1;
-						last;
+				my @streams = ();
+				foreach my $av (qw(video audio)) {
+					while ($latest =~ s#\"${av}_url\"\:\"([^\"]+)##s) {
+						my $streamURL = uri_unescape($1);
+						next  if ($self->{'secure'} && $streamURL !~ /^https/o);
+
+						push @streams, $streamURL;
 					}
 				}
+				next  unless ($#streams >= 0);  #SKIP EPISODE IF NO STREAMS.
+
+				#EPISODES HERE HAVE INCOMPLETE DATA, SO SCRAPE ENOUGH FOR PLAYLIST ENTRIES,
+				#SAVE IN THE HASH, AND HOPE THEY SHOW UP AGAIN IN THE MAIN EPISODE-LIST,
+				#THAT WAY, THEY'LL STILL APPEAR IN THE PLAYLIST, AND IF THE MAIN LIST IS
+				#EMPTY, WE CAN USE THIS AND FETCH THE REST OF THE DATA VIA THEN FETCHING
+				#THE EPISODE PAGE:
+				my $created = $1  if ($latest =~ m#\"air_date\"\:\"([^\"]+)#s);
+				my $ep1id = $1  if ($latest =~ m#\"id\"\:\"?(\d+)#s);
+				next  unless ($ep1id);  #SKIP EPISODE IF NO EPISODE-ID (SHOULD NOT HAPPEN).
+
+				my $title = $1  if ($latest =~ m#\"title\"\:\"([^\"]+)#s);
+				my $epikey = "$created|$title";
+				print STDERR "---FOUND ($special) EPISODE($created): $title ($streams[0])\n"  if ($DEBUG);
+				$epiHash{$epikey} = "id=$ep1id\x02_complete=0";
+				$epiHash{$epikey} .= "\x02streamstr=";
+				foreach my $s (@streams) {
+					$epiHash{$epikey} .= $s . '|';
+				}
+				$epiHash{$epikey} =~ s#\|$##o;
 			}
 		}
 
 		#NOTE:  Podchaser.com HAS AN ABBREVIATED LIST OF MOST RECENT EPISODES SORTED IN REVERSE ORDER
 		#(LATEST|FEATURED, THEN OLDEST TO NEWEST):
 		$html =~ s#^.+?\"episodes\"\:\{##s;
-		while ($html =~ s#^(.+?)\"user_data\"\:\{##s) {
+		while ($html =~ s#^(.+?)\"user_data\"\:\{##so) {
 			my $epihtml = $1;
-			my $streamURL = $1  if ($epihtml =~ m#\"audio_url\"\:\"([^\"]+)#);
-			next  if ($self->{'secure'} && $streamURL !~ /^https/o);
-			$ep1url ||= $1  if ($epihtml =~ m#\"(\d+)\"\:\{#);
+			#SCRAPE THE STREAM(S) FOR EACH EPISODE (WE DON'T KNOW WHICH ONE IS LATEST YET):
+			my @streams = ();
+			foreach my $av (qw(video audio)) {
+				while ($epihtml =~ s#\"${av}_url\"\:\"([^\"]+)##s) {
+					my $streamURL = uri_unescape($1);
+					next  if ($self->{'secure'} && $streamURL !~ /^https/o);
 
-			if (!defined($epiHash{$streamURL}) && $epihtml =~ m#\"title\"\:\"([^\"]+)#o) {
-				my $title = $1;
-				unshift @epiStreams, $streamURL;
-				unshift @epiTitles, $title;
-				$epiHash{$streamURL} = 1;
-				$ep1url ||= $self->{'albumartist'} . '/' . $1  if ($epihtml =~ m#\"(\d+)\"\:\{#);
+					push @streams, $streamURL;
+				}
+			}
+			next  unless ($#streams >= 0);  #SKIP EPISODE IF NO STREAMS.
+
+			my $epid = $1  if ($epihtml =~ m#\"(\d+)\"\:\{#o);
+			next  unless ($epid);  #SKIP EPISODE IF NO EPISODE-ID (SHOULD NOT HAPPEN).
+
+			#SCRAPE THE DETAILED METADATA FOR EACH EPISODE (WE DON'T KNOW WHICH ONE IS LATEST YET):
+			if ($epihtml =~ s#\,\"podcast_id\"\:\"?(\d+)\"?\,\"title\"\:\"([^\"]+)##o) {
+				my $temp;
+				$temp->{'_podcast_id'} = $1;
+				$temp->{'title'} = $2;
+				foreach my $field (qw(album genre created year iconurl articonurl description)) {
+					$temp->{$field} = '';   #INIT 'EM TO AVOID PERL NANNY WARNINGS.
+				}
+				if ($epihtml =~ m#\"air_date\"\:\"([^\"]+)#so) {
+					$temp->{'created'} = $1;
+					$temp->{'year'} = ($temp->{'created'} =~ /(\d\d\d\d)/o) ? $1 : '';
+				}
+				$temp->{'articonurl'} = $self->{'articonurl'};
+				$temp->{'articonurl'} ||= $1  if ($epihtml =~ m#\:\{\"image_url\"\:\"([^\"]+)#o);
+				$temp->{'iconurl'} = $1  if ($epihtml =~ m#\,\"image_url\"\:\"([^\"]+)#o);
+				$temp->{'album'} = $1  if ($epihtml =~ m#\,\"title\"\:\"([^\"]+)#o);
+				$temp->{'description'} = $1  if ($epihtml =~ m#\,\"description\"\:\"([^\"]+)#o);
+				$temp->{'genre'} = $1  if ($epihtml =~ m#\,\"text\"\:\"([^\"]+)#o);
+				$temp->{'_complete'} = 1;
+				@{$temp->{'streams'}} = @streams;
+
+				#STORE SCRAPED METADATA IN EPISODE HASH FOR LATER SORTING:
+				my $epikey = "$$temp{'created'}|$$temp{'title'}";
+				$epiHash{$epikey} = "id=$epid";
+				foreach my $field (qw(_complete _podcast_id album genre created year iconurl articonurl description)) {
+					$epiHash{$epikey} .= "\x02${field}=$$temp{$field}";
+				}
+				$epiHash{$epikey} .= "\x02streamstr=";
+				foreach my $s (@{$temp->{'streams'}}) {
+					$epiHash{$epikey} .= $s . '|';
+				}
+				$epiHash{$epikey} =~ s#\|$##o;
 			}
 		}
-		#NOW PUT THE FIRST/LATEST EPISODE ON TOP:
-		if ($ep1Stream && $ep1Title) {
-			unshift @epiStreams, $ep1Stream;
-			unshift @epiTitles, $ep1Title;
+
+		#NOW SET UP THE PLAYLIST AND SORT EPISODES BY AIRING DATA/TIME,TITLE (AVOIDING DUPLICATE TITLES):
+		my $first = 1;
+		my ($name, $value);
+		foreach my $epikey (sort { $b cmp $a } keys %epiHash) {
+			my @data = split(/\x02/o, $epiHash{$epikey});
+			if ($first) {  #LOOK FOR 1ST (LATEST) EPISODE W/COMPLETE DATA TO BE THE EPISODE RETURNED:
+				(undef, $self->{'title'}) = split(/\|/o, $epikey);
+				foreach my $f (@data) {
+					($name, $value) = split(/\=/o, $f);
+					$self->{$name} = $value;
+				}
+				$first = 0  if ($self->{'_complete'});  #STOP LOOKING IF EPISODE HAS COMPLETE DATA.
+				@{$self->{'streams'}} = split(/\|/o, $self->{'streamstr'});
+				$self->{'Url'} = ${$self->{'streams'}}[0];
+				unless ($titleHash{$self->{'title'}}) { #ADD TO PLAYLIST UNLESS DUPLICATE TITLE:
+					push @epiTitles, $self->{'title'};
+					push @epiStreams, ${$self->{'streams'}}[0];
+					$titleHash{$self->{'title'}} = 1;
+				}
+				delete $self->{'streamstr'};
+			} else {  #WE ALREADY HAVE OUR COMPLETE EPISODE, SO JUST ADD REST TO PLAYLIST:
+				my (undef, $epiTitle) = split(/\|/o, $epikey);
+				next  if ($titleHash{$epiTitle});
+
+				foreach my $f (@data) {
+					($name, $value) = split(/\=/o, $f);
+					if ($name eq 'streamstr') {
+						my ($epiStream) = split(/\|/o, $value);
+						push @epiTitles, $epiTitle;
+						push @epiStreams, $epiStream;
+						$titleHash{$epiTitle} = 1;
+						last  if ($self->{'id'});
+					} elsif ($name eq 'id') {
+						$self->{'id'} ||= $value;
+					}
+				}
+			}
 		}
 		if ($DEBUG) {
-			print STDERR "--ep1url=$ep1url= artist=".$self->{'artist'}."= articon=".$self->{'articonurl'}."=\n";
+			print STDERR "--ep1id=".$self->{'id'}."= title=".$self->{'title'}."= First=".$self->{'Url'}."=\n";
 			for (my $i=0;$i<=$#epiStreams;$i++) {
-				print STDERR "-----EPISODE($epiTitles[$i]): $epiStreams[$i]\n";
+				print STDERR "-----EPISODE: $epiTitles[$i] ($epiStreams[$i])\n";
 			}
 		}
-		if ($ep1url) {   #WE FOUND AN EPISODE, SO RETRY TO FETCH THE EPISODE PAGE:
+		if ($self->{'id'} && $tried < 1 && !$self->{'_complete'}) {   #EMPTY EP. LIST, BUT HAVE LATEST|FEATURED (INCOMPLETE DATA, MUST FETCH EP. PAGE)!:
 			++$tried;
-			$url2fetch = $ep1url;
-			print STDERR "-!!!!- RETRY w/1ST EPISODE URL=$url2fetch=\n"  if ($DEBUG);
+			$url2fetch .= '/episodes/' . $self->{'id'};
+			print STDERR "i:No episode list, but have featured episode($$self{'id'}), BUT INCOMPLETE DATA, SO FETCH URL=$url2fetch=\n"  if ($DEBUG);
 			goto TRYIT;
-		} else {
-			print STDERR "e:Podcast ($url2fetch) has no episodes!\n";
 		}
 	}
 
+	$self->{'imageurl'} ||= $self->{'iconurl'};
+	$self->{'artimageurl'} ||= $self->{'articonurl'};
+	$self->{'cnt'} = scalar(@{$self->{'streams'}});
 	$self->{'total'} = $self->{'cnt'};
 	$self->{'Url'} = ($self->{'total'} > 0) ? $self->{'streams'}->[0] : '';
 
-	print STDERR "-(all)count=".$self->{'total'}."= ID=".$self->{'id'}."= iconurl="
-			.$self->{'iconurl'}."= TITLE=".$self->{'title'}."= DESC=".$self->{'description'}
-			."= YEAR=".$self->{'year'}."=\n"  if ($DEBUG);
+	if ($DEBUG) {
+		foreach my $i (sort keys %{$self}) {
+			print STDERR "--KEY=$i= VAL=".$self->{$i}."=\n";
+		}
+		print STDERR "--FIRST STREAM=".${$self->{'streams'}}[0]."=\n";
+		print STDERR "-(all)count=".$self->{'total'}."= ID=".$self->{'id'}."= iconurl="
+				.$self->{'iconurl'}."= TITLE=".$self->{'title'}."= DESC=".$self->{'description'}
+				."= YEAR=".$self->{'year'}."=\n";
+	}
+
 	return undef  unless ($self->{'cnt'} > 0);
 
 	#GENERATE EXTENDED-M3U PLAYLIST (NOTE: MAY NOT BE ABLE TO UNTIL USER CALLS $podcast->get('playlist')!):
